aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthew Hoops2007-03-18 23:35:24 +0000
committerMatthew Hoops2007-03-18 23:35:24 +0000
commit96823c885fa1d7da93e7fc64b37d8e2110d22882 (patch)
tree4523d238c8b7545bccb2725898401348b4834dbc
parent82220883d1c82e107a68927a0af6f75b1480f5e1 (diff)
downloadscummvm-rg350-96823c885fa1d7da93e7fc64b37d8e2110d22882.tar.gz
scummvm-rg350-96823c885fa1d7da93e7fc64b37d8e2110d22882.tar.bz2
scummvm-rg350-96823c885fa1d7da93e7fc64b37d8e2110d22882.zip
updating shake.screen warning/comment to reflect that AGIPAL uses it, and not AGIMOUSE
svn-id: r26237
-rw-r--r--engines/agi/op_cmd.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/agi/op_cmd.cpp b/engines/agi/op_cmd.cpp
index 3a29983f2e..39f45a1105 100644
--- a/engines/agi/op_cmd.cpp
+++ b/engines/agi/op_cmd.cpp
@@ -1227,11 +1227,11 @@ cmd(mouse_posn) {
cmd(shake_screen) {
int i;
/* AGI Mouse 1.1 uses shake.screen values between 100 and 109 to
* set the palette.
*/
- if ((g_agi->getFeatures() & GF_AGIMOUSE) && p0 >= 100 && p0 < 110) {
- report("not implemented: AGI Mouse palettes\n");
+ if ((g_agi->getFeatures() & GF_AGIPAL) && p0 >= 100 && p0 < 110) {
+ report("not implemented: AGIPAL palettes\n");
return;
} else
g_gfx->shakeStart();
@@ -1227,11 +1227,11 @@ cmd(mouse_posn) {
cmd(shake_screen) {
int i;
- /* AGI Mouse 1.1 uses shake.screen values between 100 and 109 to
+ /* AGIPAL uses shake.screen values between 100 and 109 to
* set the palette.
*/